@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -124,7 +124,7 @@ AddAvailabilityZonesInputRequestTypeDef = TypedDict(
     "AddAvailabilityZonesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "AvailabilityZones": List[str],
+        "AvailabilityZones": Sequence[str],
     },
 )
 
@@ -139,8 +139,8 @@ AddAvailabilityZonesOutputTypeDef = TypedDict(
 AddTagsInputRequestTypeDef = TypedDict(
     "AddTagsInputRequestTypeDef",
     {
-        "LoadBalancerNames": List[str],
-        "Tags": List["TagTypeDef"],
+        "LoadBalancerNames": Sequence[str],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -166,7 +166,7 @@ ApplySecurityGroupsToLoadBalancerInputRequestTypeDef = TypedDict(
     "ApplySecurityGroupsToLoadBalancerInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "SecurityGroups": List[str],
+        "SecurityGroups": Sequence[str],
     },
 )
 
@@ -182,7 +182,7 @@ AttachLoadBalancerToSubnetsInputRequestTypeDef = TypedDict(
     "AttachLoadBalancerToSubnetsInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "Subnets": List[str],
+        "Subnets": Sequence[str],
     },
 )
 
@@ -251,17 +251,17 @@ _RequiredCreateAccessPointInputRequestTypeDef = TypedDict(
     "_RequiredCreateAccessPointInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "Listeners": List["ListenerTypeDef"],
+        "Listeners": Sequence["ListenerTypeDef"],
     },
 )
 _OptionalCreateAccessPointInputRequestTypeDef = TypedDict(
     "_OptionalCreateAccessPointInputRequestTypeDef",
     {
-        "AvailabilityZones": List[str],
-        "Subnets": List[str],
-        "SecurityGroups": List[str],
+        "AvailabilityZones": Sequence[str],
+        "Subnets": Sequence[str],
+        "SecurityGroups": Sequence[str],
         "Scheme": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -317,7 +317,7 @@ CreateLoadBalancerListenerInputRequestTypeDef = TypedDict(
     "CreateLoadBalancerListenerInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "Listeners": List["ListenerTypeDef"],
+        "Listeners": Sequence["ListenerTypeDef"],
     },
 )
 
@@ -332,7 +332,7 @@ _RequiredCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
 _OptionalCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
     "_OptionalCreateLoadBalancerPolicyInputRequestTypeDef",
     {
-        "PolicyAttributes": List["PolicyAttributeTypeDef"],
+        "PolicyAttributes": Sequence["PolicyAttributeTypeDef"],
     },
     total=False,
 )
@@ -363,7 +363,7 @@ DeleteLoadBalancerListenerInputRequestTypeDef = TypedDict(
     "DeleteLoadBalancerListenerInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "LoadBalancerPorts": List[int],
+        "LoadBalancerPorts": Sequence[int],
     },
 )
 
@@ -379,7 +379,7 @@ DeregisterEndPointsInputRequestTypeDef = TypedDict(
     "DeregisterEndPointsInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "Instances": List["InstanceTypeDef"],
+        "Instances": Sequence["InstanceTypeDef"],
     },
 )
 
@@ -394,7 +394,7 @@ DeregisterEndPointsOutputTypeDef = TypedDict(
 DescribeAccessPointsInputRequestTypeDef = TypedDict(
     "DescribeAccessPointsInputRequestTypeDef",
     {
-        "LoadBalancerNames": List[str],
+        "LoadBalancerNames": Sequence[str],
         "Marker": str,
         "PageSize": int,
     },
@@ -437,7 +437,7 @@ _RequiredDescribeEndPointStateInputRequestTypeDef = TypedDict(
 _OptionalDescribeEndPointStateInputRequestTypeDef = TypedDict(
     "_OptionalDescribeEndPointStateInputRequestTypeDef",
     {
-        "Instances": List["InstanceTypeDef"],
+        "Instances": Sequence["InstanceTypeDef"],
     },
     total=False,
 )
@@ -477,7 +477,7 @@ DescribeLoadBalancerPoliciesInputRequestTypeDef = TypedDict(
     "DescribeLoadBalancerPoliciesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "PolicyNames": List[str],
+        "PolicyNames": Sequence[str],
     },
     total=False,
 )
@@ -493,7 +493,7 @@ DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
 DescribeLoadBalancerPolicyTypesInputRequestTypeDef = TypedDict(
     "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
     {
-        "PolicyTypeNames": List[str],
+        "PolicyTypeNames": Sequence[str],
     },
     total=False,
 )
@@ -509,7 +509,7 @@ DescribeLoadBalancerPolicyTypesOutputTypeDef = TypedDict(
 DescribeTagsInputRequestTypeDef = TypedDict(
     "DescribeTagsInputRequestTypeDef",
     {
-        "LoadBalancerNames": List[str],
+        "LoadBalancerNames": Sequence[str],
     },
 )
 
@@ -525,7 +525,7 @@ DetachLoadBalancerFromSubnetsInputRequestTypeDef = TypedDict(
     "DetachLoadBalancerFromSubnetsInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "Subnets": List[str],
+        "Subnets": Sequence[str],
     },
 )
 
@@ -742,7 +742,7 @@ RegisterEndPointsInputRequestTypeDef = TypedDict(
     "RegisterEndPointsInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "Instances": List["InstanceTypeDef"],
+        "Instances": Sequence["InstanceTypeDef"],
     },
 )
 
@@ -758,7 +758,7 @@ RemoveAvailabilityZonesInputRequestTypeDef = TypedDict(
     "RemoveAvailabilityZonesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "AvailabilityZones": List[str],
+        "AvailabilityZones": Sequence[str],
     },
 )
 
@@ -773,8 +773,8 @@ RemoveAvailabilityZonesOutputTypeDef = TypedDict(
 RemoveTagsInputRequestTypeDef = TypedDict(
     "RemoveTagsInputRequestTypeDef",
     {
-        "LoadBalancerNames": List[str],
-        "Tags": List["TagKeyOnlyTypeDef"],
+        "LoadBalancerNames": Sequence[str],
+        "Tags": Sequence["TagKeyOnlyTypeDef"],
     },
 )
 
@@ -803,7 +803,7 @@ SetLoadBalancerPoliciesForBackendServerInputRequestTypeDef = TypedDict(
     {
         "LoadBalancerName": str,
         "InstancePort": int,
-        "PolicyNames": List[str],
+        "PolicyNames": Sequence[str],
     },
 )
 
@@ -812,7 +812,7 @@ SetLoadBalancerPoliciesOfListenerInputRequestTypeDef = TypedDict(
     {
         "LoadBalancerName": str,
         "LoadBalancerPort": int,
-        "PolicyNames": List[str],
+        "PolicyNames": Sequence[str],
     },
 )
 
